<!--
SPDX-FileCopyrightText: 2020 G2Elab / MAGE

SPDX-License-Identifier: Apache-2.0
-->

Authors: 
=======
 B. DELINCHANT, L. GERBAUD, F. WURTZ

Main Contributors: 
=================


Contributors: 
=============
Sacha Hodencq